import StreamZip, { ZipEntry } from 'node-stream-zip';
import {orderBy}from 'natural-orderby';

export async function readZip(path : string):Promise<StreamZip>{
    return new Promise((resolve,reject)=>{
            let zip = new StreamZip({
                file:path,
                storeEntries: true
            });
            zip.on('error',(err)=>{
                console.error(`read zip file ${path}`);
                reject(err);
            });
            zip.on('ready',()=>{
                resolve(zip);
            });
        }
    );
}
export function entriesByNaturalOrder(zip: StreamZip){
    const entries = zip.entries();
    const ret = orderBy(Object.values(entries),v=>v.name);
    return ret;
}
export async function createReadStreamFromZip(zip:StreamZip,entry: ZipEntry):Promise<NodeJS.ReadableStream>{
    return new Promise((resolve,reject)=>{
        zip.stream(entry,(err, stream)=>{
            if(stream !== undefined){
                resolve(stream);
            }
            else{
                reject(err);
            }
        });}
    );
}